@@ -4,8 +4,8 @@ use std::env;
 use std::fmt::Display;
 use std::fs;
 
+use crate::embedded::Compiled;
 use crate::model::Model;
-use crate::template::Compiled;
 
 #[derive(Clone, Debug, PartialEq)]
 pub struct Version(u8, u8, u8);
