@@ -17,7 +17,7 @@ pub fn render_page(
             &json!({
                 "context": &data,
                 "project": context.project,
-                "models": context.project.models
+                "models": context.project.models,
             }),
         )
         .unwrap();
