@@ -66,6 +66,24 @@ fn form_field_helper(
     Ok(())
 }
 
+fn field_value_helper(
+    h: &Helper,
+    _hb: &Handlebars,
+    _ctx: &Context,
+    _rc: &mut RenderContext,
+    out: &mut dyn Output,
+) -> HelperResult {
+    let field = h.param(0).unwrap().value();
+    if field.is_string() {
+        out.write(field.as_str().unwrap())?;
+    } else if field.is_object() {
+        let model = field.get("$ref").unwrap().as_str().unwrap();
+        let ref_id = field.get("$id").unwrap().as_str().unwrap();
+        out.write(format!("{} ({})", model, ref_id).as_str())?
+    }
+    Ok(())
+}
+
 pub fn init_handlebars() -> Result<Handlebars<'static>> {
     let mut hb = Handlebars::new();
 
@@ -73,6 +91,7 @@ pub fn init_handlebars() -> Result<Handlebars<'static>> {
     hb.register_helper("json", Box::new(json_helper));
     hb.register_helper("title", Box::new(title_helper));
     hb.register_helper("form_field", Box::new(form_field_helper));
+    hb.register_helper("field_value", Box::new(field_value_helper));
 
     // Register parts
     for path in Parts::iter() {
